@@ -303,4 +303,10 @@ class MMSSender:
 		print "MMSC STATUS:", res.status, res.reason
 		out = res.read()
 		print "MMSC RESPONDED:", out
-		return res.status, res.reason, out
\ No newline at end of file
+		
+		decoder = mms_pdu.MMSDecoder()
+		data = array.array('B')
+		for b in out:
+			data.append(ord(b))
+		outparsed = decoder.decodeResponseHeader(data)
+		return res.status, res.reason, outparsed
\ No newline at end of file
